@@ -57,13 +57,6 @@ class ThotsbayCrawler:
             await log(e)
             return
 
-        try:
-            title = await self.parse_thread(session, url, Cascade, None)
-        except Exception:
-            await log("Error handling " + str(url))
-            return
-        # await Cascade.append_title(title)
-
         await log("Finished scrape of " + str(url), Fore.WHITE)
         return Cascade
 
@@ -179,7 +172,7 @@ class ThotsbayCrawler:
                                 0).replace("www.", ""))
                             content_links.append([embed_url, temp_title])
 
-                forum_direct_urls = [x for x in content_links if url.host in x[0].host]
+                forum_direct_urls = [x for x in content_links if x[0].host in url.host]
                 content_links = [x for x in content_links if x not in forum_direct_urls]
                 for link_title_bundle in forum_direct_urls:
                     link = link_title_bundle[0]
@@ -189,6 +182,8 @@ class ThotsbayCrawler:
                         link = URL(str(link)[:-1])
                     if 'attachments' in link.parts:
                         await Cascade.add_to_album(url.host, in_prog_title, link, url)
+                    if 'content' in link.parts:
+                        await Cascade.add_to_album(url.host, in_prog_title, link, url)
                     elif 'data' in link.parts:
                         await Cascade.add_to_album(url.host, in_prog_title, link, url)
 
@@ -211,4 +206,5 @@ class ThotsbayCrawler:
 
         except Exception as e:
             logger.debug("Error encountered while handling %s", str(url), exc_info=True)
-            logger.debug(e)
\ No newline at end of file
+            await log("Error scraping " + str(url))
+            logger.debug(e)
