@@ -8,14 +8,14 @@ from .data_classes import AuthData
 from .scraper_helper import ScrapeMapper
 
 
-async def scrape(urls, include_id: bool, thotsbay_auth: AuthData, cyberfile_auth: AuthData, separate_posts: bool):
+async def scrape(urls, include_id: bool, thotsbay_auth: AuthData, separate_posts: bool):
     await log("Starting Scrape", Fore.WHITE)
     headers = {"user-agent": user_agent}
     jar = aiohttp.CookieJar(quote_cookie=False)
 
     async with aiohttp.ClientSession(headers=headers, raise_for_status=True, cookie_jar=jar) as session:
         scraper = ScrapeMapper(session=session, include_id=include_id, thotsbay_auth=thotsbay_auth,
-                               cyberfile_auth=cyberfile_auth, separate_posts=separate_posts)
+                               separate_posts=separate_posts)
         tasks = []
         for link in urls:
             tasks.append(scraper.map_url(link))
